==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicComboPopup__24ListMouseHandler.h <==
// public class javax.swing.plaf.basic.BasicComboPopup$ListMouseHandler

// class file dependencies
// @dep_class 1753c91cef0fc2dd java_awt_event_MouseAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 85f2b7ff9c34ade6 javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler

// header file dependencies
// @dep_header java_awt_event_MouseAdapter

#include "java/awt/event/MouseAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler_H_
#define _JC_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicComboPopup$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$refs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$object	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vmethods	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vtable	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vtype	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$method$_init$57edbc699feab65e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$object *, struct _jc_javax_swing_plaf_basic_BasicComboPopup$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$method$mousePressed$0e61f2afd4a13bb2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$method$mouseReleased$47ad6ad312932c8e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$object *, struct _jc_java_awt_event_MouseEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$method_info$mousePressed$0e61f2afd4a13bb2;
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$method_info$mouseReleased$47ad6ad312932c8e;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vmethods {
	void	(*mousePressed$0e61f2afd4a13bb2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mouseReleased$47ad6ad312932c8e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$object *, struct _jc_java_awt_event_MouseEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseAdapter$vmethods	java_awt_event_MouseAdapter;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vmethods	javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicComboPopup$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$refs {
    _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$sub_refs	javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler;
    _jc_java_awt_event_MouseAdapter$sub_refs	java_awt_event_MouseAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseAdapter$sub_nonrefs	java_awt_event_MouseAdapter;
    _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$sub_nonrefs	javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$object {
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vtype _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicComboPopup__24ListMouseHandler.h <==
// public class javax.swing.plaf.basic.BasicComboPopup$ListMouseHandler

// class file dependencies
// @dep_class 1753c91cef0fc2dd java_awt_event_MouseAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 85f2b7ff9c34ade6 javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler

// header file dependencies
// @dep_header java_awt_event_MouseAdapter

#include "java/awt/event/MouseAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler_H_
#define _JC_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicComboPopup$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$refs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$object	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vmethods	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vtable	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vtype	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$method$_init$57edbc699feab65e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$object *, struct _jc_javax_swing_plaf_basic_BasicComboPopup$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$method$mousePressed$0e61f2afd4a13bb2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$method$mouseReleased$47ad6ad312932c8e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$method_info$mousePressed$0e61f2afd4a13bb2;
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$method_info$mouseReleased$47ad6ad312932c8e;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vmethods {
	void	(*mousePressed$0e61f2afd4a13bb2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mouseReleased$47ad6ad312932c8e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseAdapter$vmethods	java_awt_event_MouseAdapter;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vmethods	javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicComboPopup$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$refs {
    _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$sub_refs	javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler;
    _jc_java_awt_event_MouseAdapter$sub_refs	java_awt_event_MouseAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseAdapter$sub_nonrefs	java_awt_event_MouseAdapter;
    _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$sub_nonrefs	javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$object {
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$vtype _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicComboPopup__24ListMouseHandler_H_ */
